@@ -37,7 +37,7 @@
 #include <mail/em-account-editor.h>
 #include <libedataserver/e-account.h>
 #include <e-util/e-util.h>
-#include <e-util/e-alert-dialog.h>
+#include <libevolution-utils/e-alert-dialog.h>
 #include <e-util/e-icon-factory.h>
 #include <shell/e-shell-view.h>
 #include <calendar/gui/itip-utils.h>
